By default the function will return all historical refreshes. You
can reduce the list to the most recent refreshes using the top
argument.
If request_id is provided the function will return a single refresh
status, but will still query the Power BI API for all historical entries.
If you query the top 5 most recent refreshes using the top argument,
the function will only return a status if the provided request_id is in
this list.
The status value return can be either 'Completed', 'Failed' or 'Unknown',
which means that the refresh is still in progress.