Learn R Programming

powerbiR (version 0.1.0)

pbi_delete_rows: Delete rows

Description

Deletes all rows from the specified table within the specified dataset from the specified workspace (group ID). Only applicable to push datasets.

Usage

pbi_delete_rows(group_id, dataset_id, table_name)

Value

All rows will be deleted from the specified table.

Arguments

group_id

The Power BI workspace ID.

dataset_id

The Power BI dataset ID.

table_name

The Power BI table name.

Examples

Run this code

if (FALSE) {

group_id <- "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx"
dataset_id <- "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx"
table_name <- "My Table"

pbi_delete_rows(group_id, dataset_id, table_name)
}

Run the code above in your browser using DataLab