Learn R Programming

powerbiR (version 0.1.0)

pbi_list_groups: Get a list of workspaces

Description

Returns the ids and meta data of all Power BI workspaces to which the service principal app has been granted access.

Usage

pbi_list_groups()

Arguments

Value

A data frame with workspaces.

Examples

Run this code

if (FALSE) {

pbi_list_groups()
}

Run the code above in your browser using DataLab