Learn R Programming

powerbiR (version 0.1.0)

pbi_push_dataset_schema: Push a dataset schema to Power BI

Description

Pushes a dataset schema to the specified Power BI workspace. To add rows to the dataset, use pbi_push_rows().

Usage

pbi_push_dataset_schema(schema, group_id, retention = c("none", "basicFIFO"))

Value

A dataset with tables will be created in the specified Power BI workspace.

Arguments

schema

A push-dataset schema created by pbi_schema_create().

group_id

The ID of the destination Power BI workspace.

retention

The retention policy of the dataset. Default is "none".

Examples

Run this code

if (FALSE) {

group_id <- "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx"

schema <- pbi_schema_create(
  dt_list = list(iris),
  dataset_name = "The iris dataset",
  table_name_list = list(iris)
)

pbi_push_dataset_schema(schema, group_id)
}

Run the code above in your browser using DataLab