A dataset with tables and optionally defined relationships will be
created in the specified Power BI workspace.
Arguments
dt
A data frame with rows to be added to the specified Power BI table
(table_name). The columns and data types must match the specified table.
group_id
The ID of the destination Power BI workspace.
dataset_id
The ID of the destination Power BI dataset.
table_name
The name of the destination Power BI table.
overwrite
If TRUE, existing rows will be deleted prior to adding new
rows. If FALSE, the new rows will be appended to the existing rows.
Details
The Power BI REST has a limit of 10K rows per POST rows request. This limit
is handled by splitting the data frame into chunks of 10K rows each and
pushing these chunks one at a time. However, you should manually observe the
other limitations of the API. See
https://docs.microsoft.com/en-au/rest/api/power-bi/ for more details.