powered by
Deletes all rows from the specified table within the specified dataset from the specified workspace (group ID). Only applicable to push datasets.
pbi_delete_rows(group_id, dataset_id, table_name)
All rows will be deleted from the specified table.
The Power BI workspace ID.
The Power BI dataset ID.
The Power BI table name.
if (FALSE) { group_id <- "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx" dataset_id <- "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx" table_name <- "My Table" pbi_delete_rows(group_id, dataset_id, table_name) }
Run the code above in your browser using DataLab