powered by
Returns the ids and meta data of all Power BI workspaces to which the service principal app has been granted access.
pbi_list_groups()
A data frame with workspaces.
if (FALSE) { pbi_list_groups() }
Run the code above in your browser using DataLab